#!/bin/bash
################################################################################
#
# Intel Data Center Bridging (DCB) Software
# Copyright(c) 2007-2008 Intel Corporation.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms and conditions of the GNU General Public License,
# version 2, as published by the Free Software Foundation.
#
# This program is distributed in the hope it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
#
# The full GNU General Public License is included in this distribution in
# the file called "COPYING".
#
# Contact Information:
# e1000-eedc Mailing List <e1000-eedc@lists.sourceforge.net>
# Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
#
################################################################################

# This test builds on t1, t2, t3, t4, t5 - assumes all features in sync
# This test will turn off advertise - verify behavior and then turn it on again.
# local off, peer off, peer on, local on

. ../test_fns.sh

REMOTE=$1
DEVICE=$2

#TODO - set up so that sides are w!=w and parms different to exercise oper changes
#TODO - or do again to do this. set up so that sides are w!=w and parms different to exercise oper changes

TEST="turn advertise off and then back on"
echo Running: $TEST

RESULTS=t6.out
echo $TEST > $RESULTS

# turn local advertise off

dcbtool -r sc $DEVICE pg a:0 > junk
check_results sc_pg.l1 "$TEST: turn advertise off for local pg"
dcbtool -r sc $DEVICE pfc a:0 > junk
check_results sc_pfc.l1 "$TEST: turn advertise off for local pfc"
dcbtool -r sc $DEVICE app:0 a:0 > junk
check_results sc_app.l1 "$TEST: turn advertise off for local app"

sleep 8

dcbtool -r gc $DEVICE pg > junk
check_results gc_pg.l1 "$TEST: get local pg"
dcbtool -r gc $DEVICE pfc > junk
check_results gc_pfc.l1 "$TEST: get local pfc"
dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.l1 "$TEST: get local app"

ssh $REMOTE dcbtool -r gc $DEVICE pg > junk
check_results gc_pg.r1 "$TEST: get remote pg"
ssh $REMOTE dcbtool -r gc $DEVICE pfc > junk
check_results gc_pfc.r1 "$TEST: get remote pfc"
ssh $REMOTE dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.r1 "$TEST: get remote app"

dcbtool -r go $DEVICE pg > junk
check_results go_pg.l1 "$TEST: get local oper pg"
dcbtool -r go $DEVICE pfc > junk
check_results go_pfc.l1 "$TEST: get local oper pfc"
dcbtool -r go $DEVICE app:0 > junk
check_results go_app.l1 "$TEST: get local oper app"

ssh $REMOTE dcbtool -r go $DEVICE pg > junk
check_results go_pg.r1 "$TEST: get remote oper pg"
ssh $REMOTE dcbtool -r go $DEVICE pfc > junk
check_results go_pfc.r1 "$TEST: get remote oper pfc"
ssh $REMOTE dcbtool -r go $DEVICE app:0 > junk
check_results go_app.r1 "$TEST: get remote oper app"

dcbtool -r gp $DEVICE pg > junk
check_results gp_pg.l1 "$TEST: get remote peer pg"
dcbtool -r gp $DEVICE pfc > junk
check_results gp_pfc.l1 "$TEST: get remote peer pfc"
dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.l1 "$TEST: get remote peer app"

ssh $REMOTE dcbtool -r gp $DEVICE pg > junk
check_results gp_pg.r1 "$TEST: get remote peer pg"
ssh $REMOTE dcbtool -r gp $DEVICE pfc > junk
check_results gp_pfc.r1 "$TEST: get remote peer pfc"
ssh $REMOTE dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.r1 "$TEST: get remote peer app"

# turn remote advertise off

ssh $REMOTE dcbtool -r sc $DEVICE pg a:0 > junk
check_results sc_pg.r2 "$TEST: turn advertise off for remote pg"
ssh $REMOTE dcbtool -r sc $DEVICE pfc a:0 > junk
check_results sc_pfc.r2 "$TEST: turn advertise off for remote pfc"
ssh $REMOTE dcbtool -r sc $DEVICE app:0 a:0 > junk
check_results sc_app.r2 "$TEST: turn advertise off for remote app"

sleep 8

dcbtool -r gc $DEVICE pg > junk
check_results gc_pg.l2 "$TEST: get local pg"
dcbtool -r gc $DEVICE pfc > junk
check_results gc_pfc.l2 "$TEST: get local pfc"
dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.l2 "$TEST: get local app"

ssh $REMOTE dcbtool -r gc $DEVICE pg > junk
check_results gc_pg.r2 "$TEST: get remote pg"
ssh $REMOTE dcbtool -r gc $DEVICE pfc > junk
check_results gc_pfc.r2 "$TEST: get remote pfc"
ssh $REMOTE dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.r2 "$TEST: get remote app"

dcbtool -r go $DEVICE pg > junk
check_results go_pg.l2 "$TEST: get local oper pg"
dcbtool -r go $DEVICE pfc > junk
check_results go_pfc.l2 "$TEST: get local oper pfc"
dcbtool -r go $DEVICE app:0 > junk
check_results go_app.l2 "$TEST: get local oper app"

ssh $REMOTE dcbtool -r go $DEVICE pg > junk
check_results go_pg.r2 "$TEST: get remote oper pg"
ssh $REMOTE dcbtool -r go $DEVICE pfc > junk
check_results go_pfc.r2 "$TEST: get remote oper pfc"
ssh $REMOTE dcbtool -r go $DEVICE app:0 > junk
check_results go_app.r2 "$TEST: get remote oper app"

dcbtool -r gp $DEVICE pg > junk
check_results gp_pg.l2 "$TEST: get local peer pg"
dcbtool -r gp $DEVICE pfc > junk
check_results gp_pfc.l2 "$TEST: get local peer pfc"
dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.l2 "$TEST: get local peer app"

ssh $REMOTE dcbtool -r gp $DEVICE pg > junk
check_results gp_pg.r2 "$TEST: get remote peer pg"
ssh $REMOTE dcbtool -r gp $DEVICE pfc > junk
check_results gp_pfc.r2 "$TEST: get remote peer pfc"
ssh $REMOTE dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.r2 "$TEST: get remote peer app"

# turn remote advertise on

ssh $REMOTE dcbtool -r sc $DEVICE app:0 a:1 > junk
check_results sc_app.r3 "$TEST: turn remote advertise on app"
ssh $REMOTE dcbtool -r sc $DEVICE pfc a:1 > junk
check_results sc_pfc.r3 "$TEST: turn remote advertise on pfc"
ssh $REMOTE dcbtool -r sc $DEVICE pg a:1 > junk
check_results sc_pg.r3 "$TEST: turn remote advertise on pg"

sleep 8

dcbtool -r gc $DEVICE pg > junk
check_results gc_pg.l3 "$TEST: get local pg"
dcbtool -r gc $DEVICE pfc > junk
check_results gc_pfc.l3 "$TEST: get local pfc"
dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.l3 "$TEST: get local app"

ssh $REMOTE dcbtool -r gc $DEVICE pg > junk
check_results gc_pg.r3 "$TEST: get remote pg"
ssh $REMOTE dcbtool -r gc $DEVICE pfc > junk
check_results gc_pfc.r3 "$TEST: get remote pfc"
ssh $REMOTE dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.r3 "$TEST: get remote app"

dcbtool -r go $DEVICE pg > junk
check_results go_pg.l3 "$TEST: get local oper pg"
dcbtool -r go $DEVICE pfc > junk
check_results go_pfc.l3 "$TEST: get local oper pfc"
dcbtool -r go $DEVICE app:0 > junk
check_results go_app.l3 "$TEST: get local oper app"

ssh $REMOTE dcbtool -r go $DEVICE pg > junk
check_results go_pg.r3 "$TEST: get remote oper app"
ssh $REMOTE dcbtool -r go $DEVICE pfc > junk
check_results go_pfc.r3 "$TEST: get remote oper app"
ssh $REMOTE dcbtool -r go $DEVICE app:0 > junk
check_results go_app.r3 "$TEST: get remote oper app"

dcbtool -r gp $DEVICE pg > junk
check_results gp_pg.l3 "$TEST: get local peer pg"
dcbtool -r gp $DEVICE pfc > junk
check_results gp_pfc.l3 "$TEST: get local peer pfc"
dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.l3 "$TEST: get local peer app"

ssh $REMOTE dcbtool -r gp $DEVICE pg > junk
check_results gp_pg.r3 "$TEST: get remote peer pg"
ssh $REMOTE dcbtool -r gp $DEVICE pfc > junk
check_results gp_pfc.r3 "$TEST: get remote peer pfc"
ssh $REMOTE dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.r3 "$TEST: get remote peer app"

# turn local advertise on

dcbtool -r sc $DEVICE pg a:1 > junk
check_results sc_pg.r4 "$TEST: turn local advertise on pg"
dcbtool -r sc $DEVICE pfc a:1 > junk
check_results sc_pfc.r4 "$TEST: turn local advertise on pfc"
dcbtool -r sc $DEVICE app:0 a:1 > junk
check_results sc_app.r4 "$TEST: turn local advertise on app"

sleep 8

dcbtool -r gc $DEVICE pg > junk
check_results gc_pg.l4 "$TEST: get local pg"
dcbtool -r gc $DEVICE pfc > junk
check_results gc_pfc.l4 "$TEST: get local pfc"
dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.l4 "$TEST: get local app"

ssh $REMOTE dcbtool -r gc $DEVICE pg > junk
check_results gc_pg.r4 "$TEST: get remote pg"
ssh $REMOTE dcbtool -r gc $DEVICE pfc > junk
check_results gc_pfc.r4 "$TEST: get remote pfc"
ssh $REMOTE dcbtool -r gc $DEVICE app:0 > junk
check_results gc_app.r4 "$TEST: get remote app"

dcbtool -r go $DEVICE pg > junk
check_results go_pg.l4 "$TEST: get local oper pg"
dcbtool -r go $DEVICE pfc > junk
check_results go_pfc.l4 "$TEST: get local oper pfc"
dcbtool -r go $DEVICE app:0 > junk
check_results go_app.l4 "$TEST: get local oper app"

ssh $REMOTE dcbtool -r go $DEVICE pg > junk
check_results go_pg.r4 "$TEST: get remote oper pg"
ssh $REMOTE dcbtool -r go $DEVICE pfc > junk
check_results go_pfc.r4 "$TEST: get remote oper pfc"
ssh $REMOTE dcbtool -r go $DEVICE app:0 > junk
check_results go_app.r4 "$TEST: get remote oper app"

dcbtool -r gp $DEVICE pg > junk
check_results gp_pg.l4 "$TEST: get local peer pg"
dcbtool -r gp $DEVICE pfc > junk
check_results gp_pfc.l4 "$TEST: get local peer pfc"
dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.l4 "$TEST: get local peer app"

ssh $REMOTE dcbtool -r gp $DEVICE pg > junk
check_results gp_pg.r4 "$TEST: get remote peer pg"
ssh $REMOTE dcbtool -r gp $DEVICE pfc > junk
check_results gp_pfc.r4 "$TEST: get remote peer pfc"
ssh $REMOTE dcbtool -r gp $DEVICE app:0 > junk
check_results gp_app.r4 "$TEST: get remote peer app"

cat $RESULTS
rm junk
